@@ -1,9 +1,11 @@
 
 static const char cright_years_z[] =
-   "1994, 1995, 1996, 2002, 2005";
 
-/* uudecode utility.
-   Copyright (C) 1994, 1995, 1996, 2002, 2005, 2006 Free Software Foundation, Inc.
+/* uudecode utility.   Copyright (C) */
+
+   "1994, 1995, 1996, 2002, 2005, 2006";
+
+ /* Free Software Foundation, Inc.
 
    This product is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -161,14 +163,19 @@ read_stduu (inname, outname)
 	}
     }
 
-  if (fgets (buf, sizeof(buf), stdin) == NULL
-      || strcmp (buf, "end\n"))
-    {
-      error (0, 0, _("%s: No `end' line"), inname);
-      return 1;
-    }
+  do {
+    if (fgets (buf, sizeof(buf), stdin) == NULL)
+      break;
 
-  return 0;
+    if (strcmp (buf, "end\n") == 0)
+      return 0;
+
+    if (strcmp (buf, "end\r\n") == 0)
+      return 0;
+  } while (0);
+
+  error (0, 0, _("%s: No `end' line"), inname);
+  return 1;
 }
 
 static int
